@@ -1,12 +1,10 @@
 """
+ns
 kombu.serialization
 ===================
 
 Serialization utilities.
 
-:copyright: (c) 2009 - 2012 by Ask Solem
-:license: BSD, see LICENSE for more details.
-
 """
 from __future__ import absolute_import
 
@@ -21,6 +19,7 @@ except ImportError:  # pragma: no cover
     cpickle = None  # noqa
 
 from .exceptions import SerializerNotInstalled
+from .utils import entrypoints
 from .utils.encoding import str_to_bytes, bytes_t
 
 __all__ = ['pickle', 'encode', 'decode',
@@ -295,7 +294,7 @@ def register_json():
     from anyjson import loads, dumps
 
     def _loads(obj):
-        if isinstance(obj, bytes):
+        if isinstance(obj, bytes_t):
             obj = obj.decode()
         return loads(obj)
 
@@ -377,3 +376,7 @@ register_msgpack()
 # JSON is assumed to always be available, so is the default.
 # (this matches the historical use of kombu.)
 registry._set_default_serializer('json')
+
+# Load entrypoints from installed extensions
+for ep, args in entrypoints('kombu.serializers'):
+    register(ep.name, *args)
