@@ -4,9 +4,6 @@ kombu.transport.amqplib
 
 amqplib transport.
 
-:copyright: (c) 2009 - 2012 by Ask Solem.
-:license: BSD, see LICENSE for more details.
-
 """
 from __future__ import absolute_import
 
@@ -26,7 +23,7 @@ from amqplib.client_0_8.channel import Channel as _Channel
 from amqplib.client_0_8.exceptions import AMQPConnectionException
 from amqplib.client_0_8.exceptions import AMQPChannelException
 
-from kombu.exceptions import StdChannelError
+from kombu.exceptions import StdConnectionError, StdChannelError
 from kombu.utils.encoding import str_to_bytes
 from kombu.utils.amq_manager import get_manager
 
@@ -263,17 +260,17 @@ class Message(base.Message):
 
 class Channel(_Channel, base.StdChannel):
     Message = Message
-    events = {'basic_return': []}
+    events = {'basic_return': set()}
 
     def __init__(self, *args, **kwargs):
         self.no_ack_consumers = set()
         super(Channel, self).__init__(*args, **kwargs)
 
-    def prepare_message(self, message_data, priority=None,
+    def prepare_message(self, body, priority=None,
                 content_type=None, content_encoding=None, headers=None,
                 properties=None):
         """Encapsulate data into a AMQP message."""
-        return amqp.Message(message_data, priority=priority,
+        return amqp.Message(body, priority=priority,
                             content_type=content_type,
                             content_encoding=content_encoding,
                             application_headers=headers,
@@ -307,7 +304,8 @@ class Transport(base.Transport):
 
     # it's very annoying that amqplib sometimes raises AttributeError
     # if the connection is lost, but nothing we can do about that here.
-    connection_errors = (AMQPConnectionException,
+    connection_errors = (StdConnectionError,
+                         AMQPConnectionException,
                          socket.error,
                          IOError,
                          OSError,
