@@ -6,9 +6,6 @@ Virtual transport implementation.
 
 Emulates the AMQ API for non-AMQ transports.
 
-:copyright: (c) 2009, 2012 by Ask Solem.
-:license: BSD, see LICENSE for more details.
-
 """
 from __future__ import absolute_import
 
@@ -416,6 +413,14 @@ class Channel(AbstractChannel, base.StdChannel):
     def after_reply_message_received(self, queue):
         self.queue_delete(queue)
 
+    def exchange_bind(self, destination, source='', routing_key='',
+            nowait=False, arguments=None):
+        raise NotImplementedError('transport does not support exchange_bind')
+
+    def exchange_unbind(self, destination, source='', routing_key='',
+            nowait=False, arguments=None):
+        raise NotImplementedError('transport does not support exchange_unbind')
+
     def queue_bind(self, queue, exchange=None, routing_key='', arguments=None,
             **kwargs):
         """Bind `queue` to `exchange` with `routing key`."""
@@ -432,6 +437,10 @@ class Channel(AbstractChannel, base.StdChannel):
         if self.supports_fanout:
             self._queue_bind(exchange, *meta)
 
+    def queue_unbind(self, queue, exchange=None, routing_key='',
+            arguments=None, **kwargs):
+        raise NotImplementedError('transport does not support queue_unbind')
+
     def list_bindings(self):
         for exchange in self.state.exchanges:
             table = self.get_table(exchange)
@@ -569,7 +578,7 @@ class Channel(AbstractChannel, base.StdChannel):
             return self.Message(self, payload=raw_message)
         return raw_message
 
-    def prepare_message(self, message_data, priority=None,
+    def prepare_message(self, body, priority=None,
             content_type=None, content_encoding=None, headers=None,
             properties=None):
         """Prepare message data."""
@@ -577,7 +586,7 @@ class Channel(AbstractChannel, base.StdChannel):
         info = properties.setdefault('delivery_info', {})
         info['priority'] = priority or 0
 
-        return {'body': message_data,
+        return {'body': body,
                 'content-encoding': content_encoding,
                 'content-type': content_type,
                 'headers': headers or {},
